pause off
set more off
clear


*do file for downloading sipp data from census website and combining these datasets.  Keep only the variables that I use.

*first do 2004 wave

*change working directory to temporary storage
cd ${temp_storage}



forvalues month=1/12 {
 
    local zipfile ${temp_storage}sipp04_`month'.zip
    global dataset_import ${temp_storage}l04puw`month'.dat
    global dataset_export ${temp_storage}export_temp.dta

    copy http://thedataweb.rm.census.gov/pub/sipp/2004/l04puw`month'.zip `zipfile', replace
    unzipfile `zipfile'
    quietly do ${importing_directory}sip04w1.do 

    *recode the education variable that had an error in it (http://www.census.gov/sipp/core_content/core_notes/panel_2004_EDUC_error_memo.pdf)
    replace eeducate=38 if eeducate==41 & rcollvoc==1
    replace eeducate=39 if eeducate==41 & rcollvoc==2
    replace eeducate=40 if eeducate==41 & rcollvoc==3 | rcollvoc==4
    replace eeducate=41 if eeducate<41 & rcollvoc>=6 & rcollvoc<=9

    do ${directory}sipp_edit1.do
    compress

    if `month'~=1{
        append using ${dataset_first_merge} 
    }        
             
    save ${dataset_first_merge}, replace 

   *currently I remove this dataset in the importing do file        
  *  rm ${dataset_import}  
    rm `zipfile'
    rm ${dataset_export}
    clear

 
} 



forvalues month=1/14 {
    local zipfile ${temp_storage}sipp08_`month'.zip
    global dataset_import ${temp_storage}l08puw`month'.dat
    global dataset_export ${temp_storage}export_temp.dta

    copy http://thedataweb.rm.census.gov/pub/sipp/2008/l08puw`month'.zip `zipfile', replace
    unzipfile `zipfile'
    quietly do ${importing_directory}sippl08puw1.do 
    do ${directory}sipp_edit1.do
    compress

    append using ${dataset_first_merge}                
    save ${dataset_first_merge}, replace 
        
   * rm ${dataset_import}  *removed it in the importing do file
    rm `zipfile'
    rm ${dataset_export}
    clear

} 





*now for modules.  I had to rename extra variables to be based on the year because I can some issues with merging otherwise (even with update option, missing values weren't updated if variable was already there)

*now get the wave 1 topical module data

foreach year in 04 08 {
	
    local zipfile ${temp_storage}sip`year't1.zip   
    global dataset_import ${temp_storage}p`year'putm1.dat
    global dataset_export ${temp_storage}export_temp.dta

    copy http://thedataweb.rm.census.gov/pub/sipp/20`year'/p`year'putm1.zip `zipfile', replace
    unzipfile `zipfile'
    quietly do ${importing_directory}sip`year't1.do 

    keep ssuid epppnum swave spanel tlstwrky
	 rename tlstwrky tlstwrky`year'
    compress

    save ${dataset_export}, replace
    use ${dataset_first_merge}, clear

    merge m:1 ssuid epppnum swave spanel using ${dataset_export}, nogen keep(master match) 
    save ${dataset_first_merge}, replace 
        
  *  rm ${dataset_import}  
    rm `zipfile'
    rm ${dataset_export}
    clear

}






*now get the asset data from the topical modules


foreach year in 04 08 {
	forvalues t=1/3{	
		display "start of ifs"
		if `year'==04 {
			if `t'==1{
				display "about to assign wave"
				local wave=3
			}		
			else if `t'==2{
				local wave=6
			}
		}	
		else if `year'==08 {
			if `t'==1{
				local wave=4
			}		
			else if `t'==2{
				local wave=7
			}
			else if `t'==3{
				local wave = 10
			}
		}
		*end of all the ifs

		display "end of all ifs"

		if !((`t'==3) & (`year'==04)) {  
    		local zipfile ${temp_storage}sip`year't`wave'.zip   
    		global dataset_import ${temp_storage}p`year'putm`wave'.dat
    		global dataset_export ${temp_storage}export_temp.dta

    		copy http://thedataweb.rm.census.gov/pub/sipp/20`year'/p`year'putm`wave'.zip `zipfile', replace
    		unzipfile `zipfile'
    		quietly do ${importing_directory}sip`year't`wave'.do 
		*	keep if ems==1 | ems==4 | ems==5

		*	display _N

			*in the data dictionaries, I changed the unsecured debt variable name in 08-7 and 08-10 to the previous name (thhuscbt to rhhuscbt)
    		keep ssuid epppnum spanel thhtwlth thhtheq thhvehcl rhhuscbt thhbeq

	
*			gen liquid_net`year'_`t'=thhtwlth-thhtheq-thhvehcl-thhbeq-rhhuscbt
*2/20/14, changing things around where I'm not subtracting off unsecured debt
			gen liquid_net`year'_`t'=thhtwlth-thhtheq-thhvehcl-thhbeq

			drop thhtwlth thhtheq thhvehcl rhhuscbt thhbeq
		
    		compress

    		save ${dataset_export}, replace
    		use ${dataset_first_merge}, clear

		
    		merge m:1 ssuid epppnum spanel using ${dataset_export}, nogen keep(master match) 
			pause
    		save ${dataset_first_merge}, replace 
        
  			*  rm ${dataset_import}  
    		rm `zipfile'
    		rm ${dataset_export}
    		clear
		} 
		*end if of whether to import
	}
	*end loop over t
}
*end loop over years



use ${dataset_first_merge}, clear

*get rid of 04 and 08 parts of the topical module variables
rename tlstwrky04 tlstwrky
replace tlstwrky=tlstwrky08 if spanel==2008
forvalues t=1/2{	
	rename liquid_net04_`t' liquid_net`t'
	replace liquid_net`t'=liquid_net08_`t' if spanel==2008
}

*3rd time assets seen, which is only for the 08 panel
rename liquid_net08_3 liquid_net_3


drop tlstwrky08 liquid_net08_1 liquid_net08_2

save ${dataset_first_merge}, replace 


clear


*move file to more perminate storage
copy ${dataset_first_merge} ${directory}sipp_first_merge.dta, replace
rm ${dataset_first_merge}


cd $directory 

zipfile ${directory}sipp_first_merge.dta, saving(${directory}sipp_first_merge.zip, replace)




