use  ${directory}sipp_fortran_big.dta, clear


sysdir set PLUS /home/jse4fp/private/stata

*%9.0gc


set more off
pause off

xtset id time



*replace m_wage=. if m_job==0
*replace wage=. if job==0

gen part_time=hours==20 if hours>0
gen m_part_time=m_hours==20 if m_hours>0

replace youngest=0 if kids==0
gen any_kids=kids>0

gen birth=f.kids>kids & f.youngest<2 if f.time~=.

*get an approximation of ui length from min and max ui lenght variables

gen unemp_start_temp = job==0 & time==1
egen unemp_start=max(unemp_start_temp), by(id)
replace length_unemployed = (min_unemp_length+ max_unemp_length)/2 + length_unemployed if unemp_start==1 & unemp_spell==1
replace length_unemployed=48 if length_unemployed > 48

gen m_unemp_start_temp = m_job==0 & time==1
egen m_unemp_start=max(m_unemp_start_temp), by(id)
replace m_length_unemployed = (m_min_unemp_length+ m_max_unemp_length)/2 + m_length_unemployed if m_unemp_start==1 & m_unemp_spell==1
replace m_length_unemployed=48 if m_length_unemployed > 48

drop unemp_start_temp m_unemp_start_temp

do assert.do


tempfile men
tempfile women

drop m_seam


save `men'

drop m_eeducate-m_had_job m_unemp_start m_part_time  m_rwkesr_last

gen sex=1
save `women'

use `men', clear

drop age eeducate job_no-had_job unemp_start part_time rwkesr_last


rename m_* *
gen sex=0

append using `women'


gen id2=id*2+(sex-1)
xtset id2 time 



sort id2 job_no time
by id2 job_no: gen job_time=_n

sort id2 unemp_spell time
by id2 unemp_spell: gen ui_time=_n
xtset id2 time

gen job_rev = job == 0
gen cons=1

sum 


*for job offer probability
*logit new_job cons [pw=weight], noconstant
*logit new_job cons ur_state had_job c.age##c.age white hs some_college college sex seam [pw=weight], noconstant

*logit new_job cons ur_state had_job l.length_unemployed sex seam, noconstant
logit new_job cons ur_state had_job length_employed l.length_unemployed sex seam, noconstant
outreg2  using ${directory}new_job_logit.txt, stats(coef)  noaster nonotes  replace bdec(8)


predict pr, pr
sum pr if had_job==1, detail

*stop

matrix list e(V), noheader nonames
*predict xb, xb
*sum xb, detail
*drop xb
*pause

*for wage distribtuion
gen log_wage=log(wage)
*reg log_wage cons  if job_time==1 & job==1, noconstant
*reg log_wage cons part_time ur_state c.age##c.age white hs some_college college sex  if job_time==1 & job==1, noconstant
xtreg log_wage  part_time ur_state c.age##c.age white hs some_college college sex  if job_time==1 & job==1, re 
xtreg log_wage  part_time ur_state c.age##c.age white hs some_college college sex  if job_time==1 & job==1 & time >1, re 


outreg2  using ${directory}log_wage_reg.txt, stats(coef)  noaster nonotes  replace bdec(8)

matrix list e(V)
matrix list e(V), noheader nonames

*this is to get standard deviation of the estimates of sigma_wage and part_time

*predict e, resid
*gen e2=(e*e)
*reg e2 if job_time==1 & job==1
*matrix list e(V), noheader nonames

reg part_t if job_time==1 & job==1
matrix list e(V), noheader nonames

*predict wage_hat, xb

*sum wage_hat log_wage if job_time==1 & job==1

*stop


*for husband's leisure coefficients
logit job_rev cons  if sex==0, noconstant
*logit job_rev cons c.age##c.age white hs some_college college kids youngest if sex==0 [pw=weight], noconstant
outreg2  using ${directory}husband_nowork_logit.txt, stats(coef)  noaster nonotes  replace bdec(8)
matrix list e(V), noheader nonames

*for wife's leisure coefficients
*logit job_rev cons  if sex==1 [pw=weight], noconstant
*logit job_rev cons c.age##c.age white hs some_college college kids youngest if sex==1 [pw=weight], noconstant
*logit job_rev cons c.age##c.age kids youngest if sex==1 [pw=weight], noconstant

logit job_rev cons  kids youngest if sex==1 , noconstant
outreg2  using ${directory}wife_nowork_logit.txt, stats(coef)  noaster nonotes  replace bdec(8)
matrix list e(V), noheader nonames



*for job loss probability
*logit job_loss cons ur_state c.age##c.age white hs some_college college sex f.seam c.sex#c.kids c.sex#c.youngest c.sex#c.birth [pw=weight] if job==1, noconstant
logit job_loss cons ur_state length_employed sex f.seam if job==1, noconstant
outreg2  using ${directory}job_loss_logit.txt, stats(coef)  noaster nonotes  replace bdec(8)

predict xb, xb
sum xb, detail
drop xb
pause

matrix list e(V), noheader nonames


*ui probability
*recently removed the unmp rate part since it gave me wierd results of the value function increasing with the unemployment rate
*logit ui_ever cons c.age##c.age white hs some_college college sex  [pw=weight] if ui_time==1 & unemp_spell>0 & time~=1, noconstant
logit ui_ever cons  sex  [pw=weight] if ui_time==1 & unemp_spell>0 & time~=1, noconstant
outreg2  using ${directory}ui_ever_logit.txt, stats(coef)  noaster nonotes  replace bdec(8)

predict xb, xb
sum xb, detail
drop xb
pause

*birth prob
*logit birth cons c.age##c.age kids youngest if sex==1, noconstant
logit birth cons  kids youngest if sex==1, noconstant
outreg2 using ${directory}birth_logit.txt, stats(coef)  noaster nonotes  replace bdec(8)

predict xb, xb
sum xb, detail
drop xb
pause

