pause off

set more off

use ${directory}sipp_first_merge.dta, clear



gen id_temp1=_n
egen id=min(id_temp1), by(ssuid epppnum spanel)



*egen id_wave=min(id_temp1), by(ssuid epppnum spanel swave) *for experimenting on within wave variation

gen byte time=(swave-1)*4+srefmon
xtset id time
egen min_time=min(time), by(id)
egen max_time=max(time), by(id)

*get number of observations
xtsum id


*create a seam effect dummy
gen seam=srefmon==1



*drop people who divorce
egen byte do_divorce=max(ems==4|ems==5 ), by(id)
tab do_divorce if time==min_time
drop if do_divorce==1 
drop do_divorce
drop ems

*get number of observations after droping divorce people
xtsum id



*June 2013 gen rwkesr_last here and also generate a male unemployment variable so I can see how this changes as I change my sample
gen rwkesr_last=rwkesr4
replace rwkesr_last=rwkesr5 if  rwksperm==5
gen m_unemp = rwkesr_last == 3 | rwkesr_last == 4 if esex== 1 &  rwkesr_last~=5

tab spanel if swave==1 & srefmon==1
tab rhcalyr m_unemp
tab m_unemp if rhcalyr==2010

pause


*drop people who ever have a business, which I do because I dont' think I can model the behavior of these people well
gen bus = ebno1>0 |  ebno2>0
egen ever_bus= max(bus), by(id)
tab ever_bus if time==min_time
drop if ever_bus == 1
drop bus ever_bus
drop ebno1 tsbdate1 tebdate1 erendb1 ehrsbs1 tbmsum1 ebno2 tsbdate2 tebdate2 erendb2 ehrsbs2 tbmsum2

tab spanel if swave==1 & srefmon==1
tab rhcalyr m_unemp
tab m_unemp if rhcalyr==2010

pause

*get number of observations after droping people who owned a business
xtsum id


*only keep people between the ages of 21 and 61 and drop people who ever are in school, retired, or are disables
keep if age <62 & age>=21 
gen school_ret=ersnowrk==3 | ersnowrk==4 | ersnowrk==7 
egen ever_school_ret=max(school_ret), by(ssuid epppnum spanel)
tab ever_school_ret if time==min_time
drop if ever_school_ret==1
drop school_ret ever_school_ret 
drop ersnowrk

tab spanel if swave==1 & srefmon==1
tab rhcalyr m_unemp
tab m_unemp if rhcalyr==2010


*get number of observations after droping people who were in school, retired, or disabled
xtsum id


*feb 20 2014, drop people who move
egen state_sd = sd(tfipsst), by(ssuid epppnum spanel)
drop if state_sd>0
drop state_sd

*get number of people who switch states
xtsum id


pause

/*
*june 2013 addition
*commeting this out because I ended up droping a lot of people, and the percentage that were unemployed changed

*drop people with an allocation flag for a paid job during reference period
egen ever_flag=max(apdjbthn>0), by(id)
tab ever_flag if time==min_time
drop if ever_flag==1
drop ever_flag


tab rhcalyr m_unemp
tab m_unemp if rhcalyr==2010

pause

*/

*March 2013
*there are a very small percentage of individuals in which the job id for job1 equals the id for job2, which shouldn't happen.  I'm dropping these individualas, and I might contact the census about it
gen bad_jobid= eeno1==eeno2 & eeno1 ~=-1
egen ever_bad_jobid=max(bad_jobid), by(id)
drop if ever_bad_jobid==1
drop bad_jobid ever_bad_jobid

tab spanel if swave==1 & srefmon==1
tab rhcalyr m_unemp
tab m_unemp if rhcalyr==2010

pause

*get number of observations after droping people with an error in their job id
xtsum id


*drop people who ever have imputed ui.  Also drop observations where labor force data is imputed (but I don't drop the household out of the entire sample, I just treat it as a non-interview
*June 2013, drop households in which this ever happens

egen flag=max(auectyp5==1), by(id)
replace flag=1 if eppflag==1 | ebflag==1
egen ever_flag = max(flag), by(id)
tab ever_flag if time==min_time
drop if ever_flag==1
drop flag ever_flag

tab spanel if swave==1 & srefmon==1
tab rhcalyr m_unemp
tab m_unemp if rhcalyr==2010

pause

*get number of observations after droping people with imputation of some key variables
xtsum id

*maybe drop people if alayoff==1 | alayoff==2, don't do this for now since I don't think I'll spend time focusing on search vs not search anymore



tab rhcalyr m_unemp
tab m_unemp if rhcalyr==2010

pause

*now for a bunch of labor force stuff

*March 2013, noticed error, changed the following line from rhcalmn*100 to (rhcalmn+1)*100
gen time_nextmonth=(rhcalmn+1)*100+rhcalyr*10000
replace time_nextmonth=(rhcalyr+1)*10000+1*100 if rhcalmn==12

*pause


*generate stuff related to jobs
gen lost_job=0
gen start_job=0


gen job1start=tsjdate1 if tsjdate1>-1
gen job1end=tejdate1 if tejdate1>-1
gen job1=0
replace job1=1 if eeno1>-1 & (job1start<time_nextmonth & job1start~=.)
replace start_job = 1 if eeno1>-1 & (job1start<time_nextmonth & job1start~=.)
replace job1=1 if job1start==. & tpmsum1>0
replace job1=0 if job1end<time_nextmonth & job1end~=.
replace lost_job=1 if job1end<time_nextmonth & job1end~=.

gen hours_job1=ejbhrs1 if job1==1
replace hours_job1=40 if hours_job1==-8 & (rmhrswk==1|rmhrswk==3|rmhrswk==4|rmhrswk==5) & job1==1
replace hours_job1=20 if hours_job1==-8 & (rmhrswk==2|rmhrswk==6) & job1==1

*If amount of hours still varies, recode hours variable with the usual hours worked at all jobs variable, which is less likely to have an hours vary option
replace hours_job1=ehrsall if hours_job1==-8 & job1==1
replace hours_job1=40 if hours_job1<=0 & job1==1

gen wage_job1= tpmsum1/(hours_job1*rmwkwjb) if job1==1
replace wage_job1=tpyrate1 if tpyrate1>0 & job1==1

egen wage_avg=mean(wage_job1) if job1==1, by(id job1 eeno1)

*stop

replace wage_job1=wage_avg if job1==1
drop wage_avg

replace job1=0 if wage_job1==0


* 1.09  people  had job1 end early, and after droping these people, .84 with job1==1 had no wage



gen job2start=tsjdate2 if tsjdate2>-1
gen job2end=tejdate2 if tejdate2>-1
gen job2=0
replace job2=1 if eeno2>-1 & (job2start<time_nextmonth & job2start~=.)
replace start_job = 1 if eeno2>-1 & (job2start<time_nextmonth & job2start~=.)
replace job2=1 if job2start==. & tpmsum2>0
replace job2=0 if job2end<time_nextmonth & job2end~=.
replace lost_job=1 if job2end<time_nextmonth & job2end~=.

gen hours_job2=ejbhrs2 if job2==1
replace hours_job2=40 if hours_job2==-8 & (rmhrswk==1|rmhrswk==3|rmhrswk==4|rmhrswk==5) & job2==1
replace hours_job2=20 if hours_job2==-8 & (rmhrswk==2|rmhrswk==6) & job2==1

*If amount of hours still varies, recode hours variable with the usual hours worked at all jobs variable, which is less likely to have an hours vary option
replace hours_job2=ehrsall if hours_job2==-8 & job2==1
replace hours_job2=40 if hours_job2<=0 & job2==1

gen wage_job2= tpmsum2/(hours_job2*rmwkwjb) if job2==1
replace wage_job2=tpyrate2 if tpyrate2>0 & job2==1

egen wage_avg=mean(wage_job2) if job2==1, by(id job2 eeno2)
replace wage_job2=wage_avg if job2==1
drop wage_avg

replace job2=0 if wage_job2==0




*for generating primary job, give preference for employed positions

gen job_no=0
replace job_no=eeno1 if job1==1 & job2==0
replace job_no=eeno2 if job1==0 & job2==1
replace job_no=eeno1 if job1==1 & job2==1  &  ejbhrs1>=ejbhrs2
replace job_no=eeno2 if job1==1 & job2==1 & ejbhrs1<ejbhrs2

gen job = job_no>0



*now for making the job variables congruent with the weekly labor force data


gen break=(rmesr>=3)


*March 2013 change
*In the data, sometimes it's recorded with the rmesr variable that the person had a job every week of the month, but for the ersend tejdate variable, it's recorded that they were layed off at the end of the month.  The following change that into account.  In order to ignore a secondary job ending (which I ignore for the purposes of my model), I only make this change if the job no from the last month doesn't equal the job no from this month

replace break=1 if job_no ~= l.job_no & lost_job==1

*June 2013, if had job but are recorded as being on layoff with the rwkesr_last job, then count these people as being without a job
replace job=0 		if job==1 	& rwkesr_last >=3
replace job_no=0 	if job_no>0 & rwkesr_last >=3

*June 2013, decided to count these emp_prob people as without a job, seems they have jobs but aren't receiving any money from them
/*gen emp_prob = ( job == 0 & rwkesr_last <=2 & lost_job==0)
egen ever_emp_prob = max(emp_prob), by(id)
tab ever_emp_prob if time==min_time*/


*June 2013, decided to count unemp_prob people as unemployd, looks like some people are on layoff but there's jobs may not have totally ended
/*gen unemp_prob =  (job == 1 & rwkesr_last >=4 & start_job==0)
egen ever_unemp_prob = max(unemp_prob), by(id)
tab ever_unemp_prob if time==min_time

drop if ever_emp_prob==1 | ever_unemp_prob==1
drop emp_prob ever_emp_prob unemp_prob ever_unemp_prob
*/



tab spanel if swave==1 & srefmon==1
tab rhcalyr m_unemp
tab m_unemp if rhcalyr==2010

pause




*generates some additional job related variables

gen hours=0
replace hours=hours_job1 if job_no==eeno1 & job==1
replace hours=hours_job2 if job_no==eeno2 & job==1

gen wage=0
replace wage=wage_job1 if job_no==eeno1 & job==1
replace wage=wage_job2 if job_no==eeno2 & job==1


replace hours=40 if hours>=35 & job==1
replace hours=20 if hours<35 & hours>0 & job==1


assert wage ~=. if hours>0 

gen job_start_date=.
replace job_start_date=job1start if job_no==eeno1 & job==1 
replace job_start_date=job2start if job_no==eeno2 & job==1


gen end_reason=0
replace end_reason=ersend1 if job_no==eeno1 & job==1
replace end_reason=ersend2 if job_no==eeno2 & job==1



*tab hours if job_no>0
*tab rmwkwjb if job_no>0
*confirmed that hours and weeks with job are all greater than 0

*save $dataset_main_edit, replace




*changing things around after response to quite question, ignore break in employed under a month long if due to quiting to take another job
replace break=0 if l.job_no~=job_no & job_no>0 & l.job_no>0 & end_reason==12


replace break=0 if l.job_no~=f.job_no & job_no==0 & l.job_no>0 & f.job_no>0 & end_reason==12 

replace wage=f.wage if l.job_no~=f.job_no & job_no==0 & l.job_no>0 & f.job_no>0 & end_reason==12 
replace hours=f.hours if l.job_no~=f.job_no & job_no==0 & l.job_no>0 & f.job_no>0 & end_reason==12 
replace job_no=f.job_no if l.job_no~=f.job_no & job_no==0 & l.job_no>0 & f.job_no>0 & end_reason==12 

assert wage ~=. if hours>0



gen ui=t05amt>0 if job==0



*replace wage with average wage again for cases of job#2 becoming job#1 (so they wouldn't be matched earlier)
egen wage_avg=mean(wage) if job==1, by(id job job_no)
replace wage=wage_avg if job==1
drop wage_avg

tab rmesr job






*now create some demographic variables

gen white=0
replace white=1 if erace==1 & eorigin==2
gen black=0
replace black=1 if erace==2 & eorigin==2
gen latino=0
replace latino=1 if eorigin==1

gen hs=0
replace hs=1 if eeducate==39
gen college=0
replace college=1 if eeducate>=44
gen some_college=0
replace some_college=1 if eeducate>=40 & eeducate<=43





*it seems that the SIPP will randomly give one member of the household a different number for one wave.  Since this doesn't happen very often, I just drop these people when it happens.  I identify these household by two different people having the same spouse number

sort ssuid epnspous spanel
destring epppnum, generate(temp_num)
egen min_num=min(temp_num), by(ssuid epnspous spanel)
egen max_num=max(temp_num), by(ssuid epnspous spanel)
drop if min_num !=max_num
drop min_num max_num temp_num

*get number of observations after droping people who person id changes over time
xtsum id


*June 2013, droping people who are ever not interviewed for a month


xtset id time

gen interview_break = f.time==. & time~=max_time
egen ever_interview_break = max(interview_break), by(id)
tab ever_interview_break if time==min_time


drop if ever_interview_break == 1
drop interview_break ever_interview_break

*get number of observations after droping people with a break in their interview spell
xtsum id



tab rhcalyr m_unemp
tab m_unemp if rhcalyr==2010

*June 2013 found that I needed to redo some of the time variables here

drop min_time max_time

egen min_time=min(time), by(id)
egen max_time=max(time), by(id)


*stop

pause


*June 2013, decided to drop these peole instead who were out of the panel for some time
/*
*here I deal with people who are temporarily out of the SIPP Panel.  My strategy is to keep people who are only gone for 1 or 2 waves and I drop people who are gone for a longer period of time.  I replace their missing data with the data from last present wave

egen min_time=min(time), by(id)
egen max_time=max(time), by(id)

xtset id time

gen temp_start=.
replace temp_start=1 if(time~=. & l.time==. & time~=min_time)
gen temp_end=.
replace temp_end=1 if (time~=. & f.time==. & time~=max_time)
gen temp_indicator=(temp_start==1) | (temp_end==1) 
sort id temp_indicator time

gen break_length=time[_n+1]-time-1 if temp_end==1
sort id time
egen max_length=max(break_length), by(id)
drop if max_length>9 & max_length~=.

expand break_length+1 if temp_end==1,generate(duplicate)
sort id temp_end time duplicate
by id temp_end time: gen temp_time=_n-1 if temp_end==1
replace time=temp_time+time if temp_end==1
replace rhcalmn=rhcalmn+temp_time if temp_end==1
replace rhcalyr=rhcalyr+1 if rhcalmn>=13 & temp_end==1
replace rhcalmn=rhcalmn-12 if rhcalmn>=13 & temp_end==1



drop temp_start temp_end temp_indicator max_length break_length temp_time

*/



*now get lenght of employment and unemployment

*for people with start dates to job
gen job_start_year=floor(job_start_date/10000)
gen job_start_month=floor( (job_start_date-job_start_year*10000)/100)
gen length_employed=min(48,(rhcalyr-job_start_year)*12+(rhcalmn-job_start_month) ) if job_start_date~=.


assert(length_employed>=0)
gen unknown_start_date = job_start_date==.


*for people without start dates to job
sort id job_no time
by id job_no: replace length_employed=_n-1 if length_employed==. & job==1


*gen a secondary length of employment that resets when a new job is started (sometimes it seems that people go back to an old job or a secondary job becomes a main job)
gen job_length_start = 0
replace job_length_start = length_employed if time==min_time
egen length_base_temp = max(job_length_start), by(id job_no)
by id job_no: gen length_employed2 = _n -1 + length_base_temp if job==1
drop length_base_temp

gen job_length_start_temp = 0
replace job_length_start_temp = job_length_start if job_length_start ~=.
drop job_length_start
egen job_length_start = max(job_length_start_temp), by(id)
drop job_length_start_temp

replace length_employed2=48 if length_employed2>48
replace length_employed2=0 if job==0


*now for unemployment length
gen unemp_spell=0
gen length_unemployed=0

sort id time
*/

forvalues i=1/`=_N'{

	quietly replace unemp_spell=1 in `i' if (time[`i']==min_time[`i'] & job[`i']==0) 
	quietly replace unemp_spell=unemp_spell[`i'-1] in `i' if time[`i']!=min_time[`i']
	quietly replace unemp_spell=unemp_spell[`i'-1]+1 in `i' if job[`i']==0 & job[`i'-1]==1     & time[`i']!=min_time[`i']
	quietly replace length_unemployed=length_unemployed[`i'-1]+1 in `i' if job[`i']==0 & job[`i'-1]==0     & time[`i']!=min_time[`i']
}
replace unemp_spell=0 if job==1
replace length_unemployed=0 if job==1

*gen variable if ever receive ui during a particular unemployment spell
egen ui_ever=max(ui), by(id unemp_spell)
replace t05amt=t05amt/rwksperm
egen ui_ben=max(t05amt), by(id unemp_spell)




*combine the lenght variables into one variable



gen min_unemp_length=rhcalmn-1+12*(rhcalyr-tlstwrky-1) if time==min_time & rhcalyr!=tlstwrky & tlstwrky ~=-1 & tlstwrky ~=0
gen max_unemp_length=rhcalmn-1+12*(rhcalyr-tlstwrky) if  time==min_time & rhcalyr!=tlstwrky & tlstwrky ~=-1 & tlstwrky ~=0
replace min_unemp_length=0 if  time==min_time & rhcalyr==tlstwrky
replace max_unemp_length=rhcalmn-1 if  time==min_time & rhcalyr==tlstwrky
replace min_unemp = round((age - 18)*rhcalmn) if tlstwrky ==0
replace max_unemp = round((age - 18)*rhcalmn)+1 if tlstwrky ==0


gen min_unemp_length_temp = 0
replace min_unemp_length_temp = min_unemp_length if min_unemp_length ~=.
drop min_unemp_length
egen min_unemp_length = max(min_unemp_length_temp), by(id)
drop min_unemp_length_temp


gen max_unemp_length_temp = 0
replace max_unemp_length_temp = max_unemp_length if max_unemp_length ~=.
drop max_unemp_length
egen max_unemp_length = max(max_unemp_length_temp), by(id)
drop max_unemp_length_temp


gen job_loss= job==1 & f.job_no~=job_no & f.break==1 if f.time~=.

*will drop these two 
*gen keep_job= job==1 & f.job_no==job_no if f.time~=.

replace job_loss=1 if job_loss==0 & job==1 & f.job==0 
assert wage ~=. if hours>0

gen new_job=job==1 & l.job_no ~= job_no if l.time ~=.
gen had_job=l.job==1 & l.job_loss==0 if l.time~=. 



*now drop a lot of variables before getting husband and wife data side by side

drop erace eorigin tpearn epdjbthn apdjbthn eppflag eabre eptwrk aptwrk eptresn elkwrk elayoff alayoff ehrsall ebflag rmesr rwkesr1 rwkesr2 rwkesr3 rwkesr4 /// 
rwkesr5 rmwkwjb rmwksab rmwklkg awklkg rmhrswk rwksperm eeno1 tsjdate1 tejdate1 aejdate1 ersend1 ejbhrs1 tpmsum1 apmsum1 tpyrate1 eeno2 tsjdate2 tejdate2 ersend2 ///
ejbhrs2 tpmsum2 tpyrate2 euectyp5 auectyp5 t05amt t05amt a05amt tlstwrky ///
m_unemp time_nextmonth lost_job start_job job1start job1end job1 hours_job1 wage_job1 job2start ///
job2end job2 hours_job2 wage_job2 break job_start_date end_reason



*renumber job ids so that they go sequentially,commenting this out for now
*sort id job_no time
*by id job_no : gen temp1=_n
*sort id temp1 job_no
*gen temp2=0
*by id temp1: replace temp2=_n if temp1==1
*egen temp3=max(temp2), by(id job_no)
*egen min_job_no=min(job_no), by(id)
*replace temp3=temp3-1 if min_job_no==0

*replace job_no=temp3
*drop temp1 temp2 temp3 min_job_no




tempfile premerged
save `premerged'


*for merging husband's and wive's info
keep if esex==1 
foreach x of varlist _all {
		rename `x' m_`x'
}
rename m_ssuid ssuid
rename m_epppnum epnspous

*for time, merge on calander year and month
rename m_rhcalyr rhcalyr
rename m_rhcalmn rhcalmn

*used to merge based on wave and reference month
*rename m_spanel spanel
*rename m_swave swave
*rename m_srefmon srefmon 

drop m_time m_spanel m_swave m_srefmon

destring epnspous, replace

*added this compress without testing it
compress

tempfile premergedmen
save `premergedmen'

use `premerged',clear
keep if esex==2



merge 1:1 ssuid epnspous rhcalyr rhcalmn using `premergedmen', nogen keep(match)



drop id
gen id_temp=_n
egen id=min(id_temp), by(ssuid epppnum spanel) 
drop id_temp
xtset id time

drop  m_youngest m_kids

*get number of households after droping people without a matching partner
xtsum id



*bargaining related variables
gen age_dif=m_age-age

gen ed_dif=0 if eeducate==m_eeducate
replace ed_dif=1 if eeducate<m_eeducate
replace ed_dif=-1 if eeducate>m_eeducate


*normalize mean of the weights to one, 
*comment this out because I don't really need to do this
*sum wpfinwgt
*gen weight_norm=wpfinwgt/`r(mean)'
rename wpfinwgt weight


*deal with people who are unemployed at the start of the panel.  I only have the year they last worked, so I only have a range of possible values of lenght of unemployment


compress
save $dataset_main_edit, replace

drop id_temp1 m_tfipsst m_esex m_wpfinwgt m_id_temp1 m_id
drop min_time m_min_time max_time m_max_time
drop m_liquid_net1 m_liquid_net2 m_liquid_net_3
rename liquid_net_3  liquid_net3

*regenerate the min and max time variables
egen min_time=min(time), by(id)
egen max_time=max(time), by(id)


*March 2013 change
*change how kids are dealt with.  In my model, I only have an age of youngest variable, I don't have an age of other older kids, so in my model I can't account for kids aging out of the family.  Because of which, I'll have that the stock of kids continually increase (up until a max number of 6) as kids get born, but I'll have that the number of kids will never go down.  The youngest variable then can continually increase up until age 18.

gen birth = 0 
replace birth = kids>l.kids & youngest<2 if time!=min_time


*set youngest = 0 if no kids (without this, this var includes ages of adult children) and truncate number of kids at 6
replace youngest = 0 if kids==0 
replace kids = 6 if kids > 6 



forvalues i=1/`=_N'{
	*there wasn't a birth
	quietly replace kids=kids[`i'-1]      in `i' if time[`i']!=min_time[`i']  & birth[`i'] == 0   
	quietly replace youngest=min(youngest[`i'-1]+1/12,18) in `i' if time[`i']!=min_time[`i']  & birth[`i'] == 0  & kids[`i'] > 0
	
	*there was a birth
	quietly replace kids=min(kids[`i'-1]+1,6)    in `i' if time[`i']!=min_time[`i']  & birth[`i'] == 1
	quietly replace youngest=0            in `i' if time[`i']!=min_time[`i']  & birth[`i'] == 1  & kids[`i'] > 0


}


*this line needed for a new special cases where household suddenly had older children due to an adoption or some other event.  For now, I'm going to pretend these later children don't exist, it's too complicated to deal with older kid adoption in my model
replace youngest=0 if kids==0

drop birth

compress


save $dataset_main_edit, replace



