use  ${directory}sipp_fortran.dta, clear


sysdir set PLUS /home/jse4fp/private/stata


*tfipsst


set more off

gen weight2=floor(weight)
compress

xtset id time

gen m_search	= m_rwkesr_last == 3 | m_rwkesr_last == 4
gen search 		= rwkesr_last == 3 | rwkesr_last == 4


gen m_unemp=m_job==0 & m_search==1
gen unemp=job==0 & search==1
gen m_nolf=m_job==0 & m_search==0
gen nolf=job==0 & search==0

replace m_wage=. if m_job==0
replace wage=. if job==0

gen part_time=hours==20 if hours>0
gen m_part_time=m_hours==20 if m_hours>0

replace youngest=. if kids==0



tabstat age white hs some_college college kids youngest[fw=weight2] ,column(statistic) format(%-9.4f)
tabstat m_age m_white m_hs m_some_college college [fw=weight2] ,column(statistic) format(%-9.4f)

tabstat job unemp nolf part_time wage [fw=weight2] if spanel==2004, column(statistic) format(%-9.4f)
tabstat m_job m_unemp m_nolf m_part_time m_wage[fw=weight2] if spanel==2004, column(statistic) format(%-9.4f)

tabstat job unemp nolf part_time wage [fw=weight2] if spanel==2008, column(statistic) format(%-9.4f)
tabstat m_job m_unemp m_nolf m_part_time m_wage[fw=weight2] if spanel==2008, column(statistic) format(%-9.4f)

*also table could be useful

 



replace youngest=0 if kids==0


gen lf_status=1
replace lf_status=2 if unemp==1
replace lf_status=3 if nolf==1

gen m_lf_status=1
replace m_lf_status=2 if m_unemp==1
replace m_lf_status=3 if m_nolf==1

gen future_lf_status=f.lf_status
gen future_m_lf_status=f.m_lf_status

label define lf_status 1 "Employed" 2 "Unemployed" 3 "Not in LF" 
label values lf_status lf_status
label values m_lf_status lf_status
label values future_lf_status lf_status
label values future_m_lf_status lf_status


tab lf_status future_lf_status [fw=weight2], row nof
tab m_lf_status future_m_lf_status [fw=weight2], row nof



egen ever_unemp=max(unemp), by(id)
egen ever_m_unemp=max(m_unemp), by(id)
tab ever_unemp ever_m_unemp if time==1

egen ever_both_unemp=max(unemp*m_unemp), by(id)
tab ever_both_unemp if time==1


*reg job   l.m_job l.m_unemp if l.unemp==1 & nolf==0     [pw=weight], cluster(tfipsst)
*reg m_job l.job   l.unemp   if l.m_unemp==1 & m_nolf==0 [pw=weight], cluster(tfipsst) 
*reg job   l.m_job l.m_unemp if l.job==1 & nolf==0       [pw=weight], cluster(tfipsst)
*reg m_job l.job   l.unemp   if l.m_job==1 & m_nolf==0   [pw=weight], cluster(tfipsst) 
*reg unemp l.m_job l.m_unemp if l.nolf==1 & job==0       [pw=weight], cluster(tfipsst)


*tabs on the lenght of employment/unemployment and whether a job was started or ended
tab m_length_employed2 m_job_loss if m_job==1, row
tab length_employed2 job_loss if job==1, row

tab m_length_employed2 m_new_job if m_job==1, row
tab length_employed2 new_job if job==1, row

gen lag_m_length_unemployed = l.m_length_unemployed
gen lag_m_job=l.m_job
gen lag_length_unemployed = l.length_unemployed
gen lag_job=l.job

tab lag_m_length_unemployed m_new_job if lag_m_job==0, row
tab lag_length_unemployed new_job if lag_job==0, row









tabstat liquid_net1 [fw=weight2] if spanel==2004 & time==1,statistics(p10 p25 p50 p75 p90)  column(statistic) format(%-9.0f)
tabstat liquid_net2 [fw=weight2] if spanel==2004 & time==1,statistics(p10 p25 p50 p75 p90)  column(statistic) format(%-9.0f)
tabstat liquid_net1 [fw=weight2] if spanel==2008 & time==1,statistics(p10 p25 p50 p75 p90)  column(statistic) format(%-9.0f)
tabstat liquid_net2 [fw=weight2] if spanel==2008 & time==1,statistics(p10 p25 p50 p75 p90)  column(statistic) format(%-9.0f)



gen liquid_dif=liquid_net2-liquid_net1

tabstat liquid_dif [fw=weight2] if spanel==2004 & time==1,statistics(p10 p25 p50 p75 p90)  column(statistic) format(%-9.0f)
tabstat liquid_dif [fw=weight2] if spanel==2008 & time==1,statistics(p10 p25 p50 p75 p90)  column(statistic) format(%-9.0f)


*stop

*the limits in the kdensities are p10 and p90
*kdensity liquid_net1  [fweight = weight2]  if spanel==2008 & time==1& liquid_net1<383147 & liquid_net1>-17990, xlabel(#8)


*kdensity liquid_dif [fweight = weight2]  if spanel==2008 & time==1 & liquid_net1<383147 & liquid_net1>-17990 & liquid_dif<190547 & liquid_dif>-138758, xlabel(#7)




*sum liquid_net1 if spanel==2004 & time==1, detail 
*global median1_2004=r(p50)
*sum liquid_net1 if spanel==2008 & time==1, detail
*global median1_2008=r(p50)
*sum liquid_net2 if spanel==2004 & time==1, detail
*global median2_2004=r(p50)
*sum liquid_net2 if spanel==2008 & time==1, detail
*global median2_2008=r(p50)

*gen liquid_dif=(liquid_net1-$median1_2004)-(liquid_net2-$median2_2004)  if spanel==2004 & time==1
*replace liquid_dif=(liquid_net1-$median1_2008)-(liquid_net2-$median2_2008)  if spanel==2008 & time==1




*sum liquid_dif if time==1, detail
*sum liquid_dif if time==1 & ever_unemp==0 & ever_m_unemp==0, detail

*gen abs_liquid_dif=abs(liquid_dif)
*sum abs_liquid_dif if time==1 & ever_unemp==0 & ever_m_unemp==0, detail







global controls="age white hs some_college college kids youngest seam ur_state"
global m_controls="m_age m_white m_hs m_some_college m_college kids youngest seam ur_state"


*June 2013, now only doing these probits for job vs no job.


probit job   l.m_job  ${controls} if l.job==0       [pw=weight], cluster(tfipsst)
margins [pw=weight], dydx( l.m_job ) post
outreg2  l.m_job using ${directory}probit.txt, replace  dec(4)
*these results are much nicer than the previous one

probit m_job l.job  ${controls} if l.m_job==0       [pw=weight], cluster(tfipsst)
margins [pw=weight], dydx( l.job ) post
outreg2 l.job  using ${directory}probit.txt, append  dec(4)



*old distinction of unemployed vs not in lf
/*
*probit job   l.m_job l.m_unemp ${controls} if l.unemp==1 & nolf==0       [pw=weight], cluster(tfipsst)
*these results aren't as nice

probit job  l.unemp l.m_job l.m_unemp ${controls} if l.job==0       [pw=weight], cluster(tfipsst)
margins [pw=weight], dydx(l.unemp l.m_job l.m_unemp) post
outreg2 l.unemp l.m_job l.m_unemp using ${directory}probit.txt, replace  dec(4)
*these results are much nicer than the previous one


probit m_job l.m_unemp l.job l.unemp ${controls} if l.m_job==0       [pw=weight], cluster(tfipsst)
margins [pw=weight], dydx(l.m_unemp l.job l.unemp) post
outreg2 l.m_unemp l.job l.unemp using ${directory}probit.txt, append  dec(4)

*probit m_job l.job   l.unemp  ${m_controls}  if l.m_unemp==1 & m_nolf==0 [pw=weight], cluster(tfipsst) 
*margins [pw=weight], dydx(l.job l.unemp) post

probit unemp   l.m_job l.m_unemp ${controls} if l.job==1 & nolf==0         [pw=weight], cluster(tfipsst)
margins [pw=weight], dydx(l.m_job l.m_unemp) post
outreg2 l.m_job l.m_unemp using ${directory}probit.txt, append  dec(4)

probit m_unemp l.job   l.unemp  ${m_controls}  if l.m_job==1  & m_nolf==0  [pw=weight], cluster(tfipsst) 
margins [pw=weight], dydx(l.job l.unemp) post
outreg2 l.job l.unemp using ${directory}probit.txt, append tex(frag) sortvar(l.unemp l.job l.m_unemp l.m_job) dec(4)

*This one I get wierd result of wife having a job makes it more likely husband will be unemployed next time period..actually not wierd, makes sense based on selection of men with housewifes being more likely to be in stable jobs


*probit unemp l.m_job l.m_unemp ${controls} if l.nolf==1 & job==0         [pw=weight], cluster(tfipsst)
*margins [pw=weight], dydx(l.m_job l.m_unemp) post
*/


stop


probit nojob_to_job unemp m_job m_unemp $controls if job==0, cluster(tfipsst)
margins, dydx(unemp m_job m_unemp) post
outreg2 using ${directory}july4.txt, keep(unemp m_job m_unemp) replace  dec(4)
probit m_nojob_to_job m_unemp job unemp $controls if m_job==0, cluster(tfipsst)
margins, dydx(m_unemp job unemp) post
outreg2 using ${directory}july4.txt, keep(m_unemp job unemp) append  dec(4)


margins [pw=weight], dydx(l.m_job l.m_unemp) post


outreg2 using cps_results1.txt, replace title(Table 1: Regession of wife's hours worked on husband's weeks left on UI and husband's weekly UI amount)

margins [pw=pwcmpwgt], dydx(_all) post
outreg2 using "J:\private\tables\fjob.xls", replace ctitle(fjob) dec(4)

outreg2 c.wksleft_egg c.wba exhausted_egg m_unemp_length state_unemp using cps_results1.txt, append



tabstat a

gen nojob_to_job= job==0 & f.job==1 if job==0 & f.job~=.
gen job_to_nojob= job==1 & f.job==0 if job==1 & f.job~=.
gen unemp_to_job= unemp==1 & f.job==1 if unemp==1 & f.job~=.
gen nolf_to_unemp= nolf==1 & f.unemp==1 if nolf==1 & f.unemp~=.
gen keep_job= job==1 & f.job==1 if job==1 & f.job~=.
gen stay_nojob= job==0 & f.job==0 if job==0 & f.job~=.
gen stay_unemp= unemp==1 & f.unemp==1 if unemp==1 & f.unemp~=.

gen m_nojob_to_job= m_job==0 & f.m_job==1 if m_job==0 & f.m_job~=.
gen m_job_to_nojob= m_job==1 & f.m_job==0 if m_job==1 & f.m_job~=.
gen m_unemp_to_job= m_unemp==1 & f.m_job==1 if m_unemp==1 & f.m_job~=.
gen m_nolf_to_unemp= m_nolf==1 & f.m_unemp==1 if m_nolf==1 & f.m_unemp~=.
gen m_keep_job= m_job==1 & f.m_job==1 if m_job==1 & f.m_job~=.
gen m_stay_nojob= m_job==0 & f.m_job==0 if m_job==0 & f.m_job~=.
gen m_stay_unemp= m_unemp==1 & f.m_unemp==1 if m_unemp==1 & f.m_unemp~=.


gen newjob=job_no~=f.job_no if job==1 & f.job==1
gen m_newjob=m_job_no~=f.m_job_no if m_job==1 & f.m_job==1


#delimit ;

sum
job unemp nolf wage hours m_job m_unemp m_nolf m_wage m_hours
nojob_to_job job_to_nojob unemp_to_job nolf_to_unemp keep_job stay_nojob stay_unemp
m_nojob_to_job m_job_to_nojob m_unemp_to_job m_nolf_to_unemp m_keep_job m_stay_nojob m_stay_unemp
newjob m_newjob
white black latino hs college some_college
m_white m_black m_latino m_hs m_college m_some_college
age m_age kids youngest
;

#delimit cr





