use  ${directory}sipp_fortran_big.dta, clear


sysdir set PLUS /home/jse4fp/private/stata




set more off

gen weight2=floor(weight)
compress

xtset id time


*do setup for some variables

replace m_wage=. if m_job==0
replace wage=. if job==0

replace m_ui_ben=. if m_job==1
replace ui_ben=. if job==1

gen part_time=hours==20 if hours>0
gen m_part_time=m_hours==20 if m_hours>0

replace youngest=. if kids==0

gen assets=.
replace assets = liquid_net1 if time == liquid_time1
replace assets = liquid_net2 if time == liquid_time2
replace assets = liquid_net3 if time == liquid_time3

*get an approximation of ui length from min and max ui lenght variables

gen unemp_start_temp = job==0 & time==1
egen unemp_start=max(unemp_start_temp), by(id)
replace length_unemployed = (min_unemp_length+ max_unemp_length)/2 + length_unemployed if unemp_start==1 & unemp_spell==1
replace length_unemployed=48 if length_unemployed > 48

gen m_unemp_start_temp = m_job==0 & time==1
egen m_unemp_start=max(m_unemp_start_temp), by(id)
replace m_length_unemployed = (m_min_unemp_length+ m_max_unemp_length)/2 + m_length_unemployed if m_unemp_start==1 & m_unemp_spell==1
replace m_length_unemployed=48 if m_length_unemployed > 48

*now rounding length
replace length_unemployed = round(length_unemployed,1)
replace m_length_unemployed = round(m_length_unemployed,1)
replace length_employed = round(length_employed,1)
replace m_length_employed = round(m_length_employed,1)

drop unemp_start_temp m_unemp_start_temp


replace m_length_employed =. if m_job ==0
replace length_employed =. if job ==0
replace m_length_unemployed =. if m_job ==1
replace length_unemployed =. if job ==1

replace m_ui_ever = . if m_job == 1
replace ui_ever = . if job == 1
replace m_ui_ben =. if m_ui_ben==0
replace ui_ben =. if ui_ben==0

order m_job job m_wage wage m_ui_ben ui_ben m_ui_ever ui_ever m_part_time part_time m_length_employed length_employed m_length_unemployed length_unemployed ///
m_age age m_white white m_hs hs m_some_college some_college m_college college kids youngest assets





*create some temporary files for doing summary statistics 

tempfile main_file
tempfile men
tempfile women


save `main_file'

drop m_seam

save `men'


keep job wage ui_ben part_time length_employed length_unemployed age white hs some_college college kids youngest assets ui_ever

gen sex=1
save `women'

use `men', clear

keep m_job m_wage m_ui_ben m_part_time m_length_employed m_length_unemployed m_age m_white m_hs m_some_college m_college m_ui_ever


rename m_* *
gen sex=0

append using `women'



*do some labeling
label variable job "Employed"
label variable part_time "Working Part-time (Given Employed)"
label variable wage "Hourly Wage (Given Employed)"
label variable ui_ever "Receiving UI Benefits (Given not Employed)"
label variable ui_ben "UI Benefits (Given Receipt)"
label variable length_employed "Length Employed (Given Employed)"
label variable length_unemployed "Length Non-employed (Given not Employed)"
label variable age "Age"
label variable white "White"
label variable hs "High School"
label variable some_college "Some College"
label variable college "College"
label variable kids "Number of Children"
label variable youngest "Age of Youngest Child (Given have a Child)"
label variable assets "Net Liquid Assets"


estpost sum job part_time wage ui_ever ui_ben length_employed length_unemployed age white hs some_college college kids youngest assets
esttab using summary_table1.txt, cells("mean(fmt(2)) sd(fmt(2)) ") nomtitle nonumber replace tex label

estpost sum assets, detail
esttab using asset_summary.txt, cells( p5(fmt(%9.1gc)) p10 p25 p50 p75 p90 p95 ) nomtitle nonumber replace tex


use `main_file', clear


gen job_04 = job if spanel == 2004
gen part_time_04 = part_time if spanel == 2004
gen wage_04 = wage if spanel == 2004
gen ui_ever_04 = ui_ever if spanel == 2004

gen m_job_04 = m_job if spanel == 2004
gen m_part_time_04 = m_part_time if spanel == 2004
gen m_wage_04 = m_wage if spanel == 2004
gen m_ui_ever_04 = m_ui_ever if spanel == 2004

gen job_08 = job if spanel == 2008
gen part_time_08 = part_time if spanel == 2008
gen wage_08 = wage if spanel == 2008
gen ui_ever_08 = ui_ever if spanel == 2008

gen m_job_08 = m_job if spanel == 2008
gen m_part_time_08 = m_part_time if spanel == 2008
gen m_wage_08 = m_wage if spanel == 2008
gen m_ui_ever_08 = m_ui_ever if spanel == 2008



estpost tabstat m_job_04 job_04 m_job_08 job_08, columns(variables)
esttab using summary_table2.txt, cells( "m_job_04(fmt(3)) m_job_08(fmt(3)) job_04(fmt(3)) job_08(fmt(3)) ") nomtitle nonumber replace tex

estpost tabstat m_part_time_04 part_time_04 m_part_time_08 part_time_08, columns(variables)
esttab using summary_table2.txt, cells( "m_part_time_04(fmt(3)) m_part_time_08(fmt(3)) part_time_04(fmt(3)) part_time_08(fmt(3)) ") nomtitle nonumber append tex

estpost tabstat m_wage_04 wage_04 m_wage_08 wage_08, columns(variables)
esttab using summary_table2.txt, cells( "m_wage_04(fmt(1)) m_wage_08(fmt(1)) wage_04(fmt(1)) wage_08(fmt(1)) ") nomtitle nonumber append tex

estpost tabstat m_ui_ever_04 ui_ever_04 m_ui_ever_08 ui_ever_08, columns(variables)
esttab using summary_table2.txt, cells( "m_ui_ever_04(fmt(3)) m_ui_ever_08(fmt(3)) ui_ever_04(fmt(3)) ui_ever_08(fmt(3)) ") nomtitle nonumber append tex



drop m_job_04 job_04 m_job_08 job_08 m_part_time_04 part_time_04 m_part_time_08 part_time_08 m_wage_04 wage_04 m_wage_08 wage_08



label define job_label 0 "Not Employed" 1 "Employed" 

gen lag_m_job = l.m_job
gen lag_job = l.job

label values m_job job_label
label values job job_label
label values lag_m_job job_label
label values lag_job job_label


estpost tabulate lag_m_job m_job
esttab using markov_husband.txt, cell(rowpct(fmt(2))  ) unstack nomtitle nonumber eqlabels(, lhs("Lagged Employment Status") )  replace tex

estpost tabulate lag_job job
esttab using markov_wife.txt, cell(rowpct(fmt(2))  ) unstack nomtitle nonumber eqlabels(, lhs("Lagged Employment Status") )  replace tex



*now generate some survival function
*was getting wierd numbers of the graphs not going low enough, not sure what that's about
/*

gen lag_m_length_unemployed = l.m_length_unemployed
gen lag_length_unemployed = l.length_unemployed


stset lag_m_length_unemployed if lag_m_job ==0 & lag_m_length_unemployed<48, failure(m_job==1)
label variable job "Wife Employed"

sts graph, by(job) ci ytitle(Percentage Still Without a Job) ytitle(, size(medlarge)) ylabel(.7(.1)1) ///
xtitle(Number of Months Without a Job) xtitle(, size(medlarge)) subtitle(Failure: Husband Leaving Non-Employment) ///
legend(order(2 "Wife Not Working"  4 "Wife Working"))
*/





global m_controls="l.m_age l.m_white l.m_hs l.m_some_college l.m_college l.kids l.youngest seam l.ur_state"





label variable job "Wife Employed"
label variable m_job "Husband Employed"

label variable m_age "Age"
label variable m_white "White"
label variable m_hs "High School"
label variable m_some_college "Some College"
label variable m_college "College"
label variable kids "Number of Children"
label variable youngest "Age of Youngest Child (Given have a Child)"
label variable seam "Seam Effect Dummy"
label variable ur_state "State Unemployment Rate"

*do husband first

gen lag_spouse_employed = l.job
gen lag_ui_ever = l.m_ui_ever
gen lag_length_unemployed =l.m_length_unemployed


label variable lag_spouse_employed "Spouse Employed" 
label variable lag_ui_ever "UI Receipt " 
label variable lag_length_unemployed "Months without Work"

eststo: probit m_job  i.lag_spouse_employed##i.lag_ui_ever lag_length_unemployed ${m_controls} if l.m_job==0       [pw=weight], cluster(tfipsst)
margins [pw=weight], dydx( lag_spouse_employed )


drop lag_spouse_employed lag_ui_ever lag_length_unemployed


*now wife

gen lag_spouse_employed = l.m_job
gen lag_ui_ever = l.ui_ever
gen lag_length_unemployed =l.length_unemployed

label variable lag_spouse_employed "Spouse Employed" 
label variable lag_ui_ever "UI Receipt" 
label variable lag_length_unemployed "Months without Work"

replace m_age = age
replace m_white = white 
replace m_hs = hs  
replace m_some_college = some_college 
replace m_college = college

eststo: probit job  i.lag_spouse_employed##i.lag_ui_ever lag_length_unemployed ${m_controls} if l.job==0       [pw=weight], cluster(tfipsst)
margins [pw=weight], dydx( lag_spouse_employed )

esttab  using ${directory}probit_long.txt, replace nomtitle nonumber  label tex star(* 0.10 ** 0.05 *** 0.01 ) se

estimates clear


